# iMath Requests
Python package for communication with the iMath data platform REST API

[![Deployment](https://github.com/i3drobotics/imath-requests/actions/workflows/deploy.yml/badge.svg)](https://github.com/i3drobotics/imath-requests/actions/workflows/deploy.yml)

## Install
Install the package using pip:
```
python -m pip install imath-requests
```